Learn R Programming

oec (version 2.0)

install_d3plus: Installs D3 and D3plus

Description

Installs D3 and D3plus

Usage

install_d3plus()

Arguments

Value

Copies a folder named d3plus to the working directory and it contains the js files and icons to make the visualizations

Examples

Run this code
install_d3plus()

Run the code above in your browser using DataLab